@@ -67,6 +67,7 @@ class Post(object):
         community_tab_items = Post.get_items_from_community_tab(community_tab)
 
         post_data = community_tab_items[0]["backstagePostThreadRenderer"]["post"]["backstagePostRenderer"]
+        post_data["channelId"] = data["metadata"]["channelMetadataRenderer"]["externalId"]
 
         post = Post.from_data(post_data)
         post.get_first_continuation_token(data)
@@ -76,8 +77,6 @@ class Post(object):
             safely_get_value_from_key(data, "responseContext", "webResponseContextExtensionData", "ytConfigData", "sessionIndex", default="")
         )
 
-        post.channel_id = search_key("externalId", data)[0][1]
-
         return post
 
     def __str__(self):
@@ -245,9 +244,6 @@ class Post(object):
             self.channel_id.encode(),
         ]
 
-        PAD1 = b"*\x02\b\x00P\x01\xA2\x01"
-        PAD2 = b"\xAA\x01"
-
         params = urlsafe_b64encode(b"".join(params)).decode().replace("=", "%3D")
 
         return params
@@ -301,6 +297,7 @@ class Post(object):
 
         post = Post(
             data["postId"],
+            channel_id=data["channelId"],
             author={
                 "authorText": safely_get_value_from_key(data, "authorText"),
                 "authorThumbnail": safely_get_value_from_key(data, "authorThumbnail"),
